# MyDM
### 一个使用OneBot v11/12协议的机器人框架
- 暂时只支持 go-cqhttp，写的代码也都是为了go-cqhttp，目前并没有使用别的OneBot实现的打算
<!-- - 暂时只支持 array 上报数据类型 -->
- 暂时只支持 正向Http 和 正向WebSocket 通信协议

### 本项目使用Apache2.0开源协议
- 使用本项目时要求保留原始版权和许可声明。同时向贡献者明确授予专利权。
- 使用者可以自由修改，进行商业使用，可以使用不同的条款分发，没有开源要求。
